aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSimon L <szaimen@e.mail.de>2023-05-16 11:56:41 +0200
committerGitHub <noreply@github.com>2023-05-16 11:56:41 +0200
commit45ecabf7a18604a92051c797870438bd52f363bd (patch)
treeb65126d6ab7038d3c212d120f42522c4089e4505
parent9ae9f03d83560fffebc6f5b7f61548d1cbd4b323 (diff)
downloadnextcloud-server-45ecabf7a18604a92051c797870438bd52f363bd.tar.gz
nextcloud-server-45ecabf7a18604a92051c797870438bd52f363bd.zip
adjust patch
Signed-off-by: Simon L <szaimen@e.mail.de> Signed-off-by: Simon L. <szaimen@e.mail.de>
-rw-r--r--lib/private/Repair/ClearGeneratedAvatarCache.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/private/Repair/ClearGeneratedAvatarCache.php b/lib/private/Repair/ClearGeneratedAvatarCache.php
index 663366ffdfb..40892772a0a 100644
--- a/lib/private/Repair/ClearGeneratedAvatarCache.php
+++ b/lib/private/Repair/ClearGeneratedAvatarCache.php
@@ -51,9 +51,9 @@ class ClearGeneratedAvatarCache implements IRepairStep {
private function shouldRun(): bool {
$versionFromBeforeUpdate = $this->config->getSystemValue('version', '0.0.0.0');
// This job only runs if the server was on a version lower than or equal to 27.0.0 before the upgrade.
// To clear the avatar cache again, bump the version to the currently released version (and change the operator to <= if it's not the master branch) and wait for the next release.
- return version_compare($versionFromBeforeUpdate, '27.0.0', '<');
+ return version_compare($versionFromBeforeUpdate, '26.0.2', '<');
}
public function run(IOutput $output): void {
@@ -51,9 +51,9 @@ class ClearGeneratedAvatarCache implements IRepairStep {
private function shouldRun(): bool {
$versionFromBeforeUpdate = $this->config->getSystemValue('version', '0.0.0.0');
- // This job only runs if the server was on a version lower than or equal to 27.0.0 before the upgrade.
+ // This job only runs if the server was on a version lower than or equal to 26.0.2 before the upgrade.
// To clear the avatar cache again, bump the version to the currently released version (and change the operator to <= if it's not the master branch) and wait for the next release.